@@ -10,13 +10,13 @@ package Devel::Cover;
 use strict;
 use warnings;
 
-our $VERSION = "0.50";
+our $VERSION = "0.51";
 
 use DynaLoader ();
 our @ISA = "DynaLoader";
 
-use Devel::Cover::DB  0.50;
-use Devel::Cover::Inc 0.50;
+use Devel::Cover::DB  0.51;
+use Devel::Cover::Inc 0.51;
 
 use B qw( class ppname main_cv main_start main_root walksymtable OPf_KIDS );
 use B::Debug;
@@ -758,7 +758,8 @@ sub add_condition_cover
         my $name = $r->name;
         $name = $r->first->name if $name eq "sassign";
         # TODO - exec?  any others?
-        if ($name =~ /^const|s?refgen|gelem|die$/)
+        # print STDERR "Name [$name]\n";
+        if ($name =~ /^const|s?refgen|gelem|die|undef$/)
         {
             $c = [ $c->[3], $c->[1] + $c->[2] ];
             $count = 2;
@@ -1284,7 +1285,7 @@ See the BUGS file.  And the TODO file.
 
 =head1 VERSION
 
-Version 0.50 - 25th October 2004
+Version 0.51 - 29th November 2004
 
 =head1 LICENCE
 
