@@ -10,13 +10,14 @@ package Devel::Cover::Branch;
 use strict;
 use warnings;
 
-our $VERSION = "0.50";
+our $VERSION = "0.51";
 
 use base "Devel::Cover::Criterion";
 
 sub uncoverable { @_ > 1 ? $_[0][2][$_[1]] : scalar grep $_, @{$_[0][2]} }
 sub covered     { @_ > 1 ? $_[0][0][$_[1]] : scalar grep $_, @{$_[0][0]} }
 sub total       { scalar @{$_[0][0]} }
+sub value       { $_[0][0][$_[1]] }
 sub values      { @{$_[0][0]} }
 sub text        { $_[0][1]{text} }
 sub percentage
@@ -47,7 +48,7 @@ sub calculate_summary
 
     my $s = $db->{summary};
 
-    $self->[0] = [0, 0] unless @{$self->[0]};
+    $self->[0] = [0, 0] unless $self->[0] && @{$self->[0]};
 
     my $t = $self->total;
     my $u = $self->uncoverable;
@@ -103,7 +104,7 @@ Huh?
 
 =head1 VERSION
 
-Version 0.50 - 25th October 2004
+Version 0.51 - 29th November 2004
 
 =head1 LICENCE
 
