@@ -10,9 +10,9 @@ package Devel::Cover::Report::Html_basic;
 use strict;
 use warnings;
 
-our $VERSION = "0.50";
+our $VERSION = "0.51";
 
-use Devel::Cover::DB 0.50;
+use Devel::Cover::DB 0.51;
 
 use Template 2.00;
 
@@ -20,6 +20,17 @@ my $Template;
 my %Filenames;
 my %File_exists;
 
+sub print_stylesheet
+{
+    my ($db) = @_;
+    my $file = "$db->{db}/cover.css";
+    open CSS, '>', $file or return;
+    my $p = tell DATA;
+    print CSS <DATA>;
+    seek DATA, $p, 0;
+    close CSS;
+}
+
 sub print_summary
 {
     my ($db, $options) = @_;
@@ -39,21 +50,26 @@ sub print_summary
         for my $criterion (@showing)
         {
             my $pc = exists $part->{$criterion}
-                ? sprintf "%6.2f", $part->{$criterion}{percentage}
+                ? sprintf "%4.1f", $part->{$criterion}{percentage}
                 : "n/a";
 
             my $bg = "";
             if ($pc ne "n/a")
             {
-                my $c;
-                $c = $pc * 2.55;
-                $c = 255 if $c > 255;
-                if ($criterion eq "time")
-                {
-                    $c = 255 - $c;
-                    $c = 255 if $file eq "Total";
+                if ($criterion ne 'time') {
+                    $vals{$file}{$criterion}{class} = cvg_class($pc);
+                }
+                if (exists $Filenames{$file}) {
+                    if ($criterion eq 'branch') {
+                        $vals{$file}{$criterion}{link} = "$Filenames{$file}--branch.html";
+                    }
+                    elsif ($criterion eq 'condition') {
+                        $vals{$file}{$criterion}{link} = "$Filenames{$file}--condition.html";
+                    }
+                    elsif ($criterion eq 'subroutine') {
+                        $vals{$file}{$criterion}{link} = "$Filenames{$file}--subroutine.html";
+                    }
                 }
-                $bg = sprintf "#ff%02x00", $c;
             }
             $vals{$file}{$criterion}{pc} = $pc;
             $vals{$file}{$criterion}{bg} = $bg;
@@ -62,7 +78,8 @@ sub print_summary
 
     my $vars =
     {
-        title       => "Coverage report for $db->{db}",
+        title       => "Coverage Summary",
+        dbname      => $db->{db},
         showing     => \@showing,
         headers     => \@headers,
         files       => \@files,
@@ -217,8 +234,9 @@ sub print_conditions
                     condition  => $c,
                     bg         => $c->error ? "error" : "ok",
                     percentage => $c->percentage,
-                    parts      => [ map {text => $_, bg => $_ ? "ok" : "error"},
-                                        $c->values ],
+                    parts      => [ map {text => $c->value($_),
+                                         bg   => $c->error($_) ? "error" : "ok"},
+                                        0 .. $c->total - 1 ],
                     text       => $c->text,
                 };
         }
@@ -261,6 +279,7 @@ sub report
                        @{$options->{file}};
     %File_exists = map { $_ => -e } @{$options->{file}};
 
+    print_stylesheet($db);
     print_summary($db, $options);
 
     for my $file (@{$options->{file}})
@@ -278,7 +297,7 @@ package Devel::Cover::Report::Html_basic::Template::Provider;
 use strict;
 use warnings;
 
-our $VERSION = "0.50";
+our $VERSION = "0.51";
 
 use base "Template::Provider";
 
@@ -292,29 +311,10 @@ sub fetch
     $self->SUPER::fetch(exists $Templates{$name} ? \$Templates{$name} : $name)
 }
 
-$Templates{colours} = <<'EOT';
-[%
-    colours =
-    {
-        default => "#ffffad",
-        text    => "#000000",
-        number  => "#ffffc0",
-        error   => "#ff0000",
-        ok      => "#00ff00",
-    }
-%]
-
-[% MACRO bg BLOCK -%]
-bgcolor="[% colours.$colour %]"
-[%- END %]
-EOT
-
 $Templates{html} = <<'EOT';
-[% PROCESS colours %]
-
 <!--
 
-This file was generated by Devel::Cover Version 0.50
+This file was generated by Devel::Cover Version 0.51
 
 Devel::Cover is copyright 2001-2002, Paul Johnson (pjcj@cpan.org)
 
@@ -329,11 +329,14 @@ http://www.pjcj.net
 <!DOCTYPE html
     PUBLIC "-//W3C//DTD XHTML Basic 1.0//EN"
     "http://www.w3.org/TR/xhtml-basic/xhtml-basic10.dtd">
-<html xmlns="http://www.w3.org/1999/xhtml" lang="en-US">
+<html xmlns="http://www.w3.org/1999/xhtml">
 <head>
+    <meta http-equiv="Content-Type" content="text/html; charset=iso-8859-1"></meta>
+    <meta http-equiv="Content-Language" content="en-us"></meta>
+    <link rel="stylesheet" type="text/css" href="cover.css"></link>
     <title> [% title %] </title>
 </head>
-<body [% bg(colour = "default") %] text="[% colours.text %]">
+<body>
     [% content %]
 </body>
 </html>
@@ -342,34 +345,47 @@ EOT
 $Templates{summary} = <<'EOT';
 [% WRAPPER html %]
 
-<h1> [% title %] </h1>
+<h1>[% title %]</h1>
+<table>
+    <tr>
+        <td class="header" align="right">Database:</td>
+        <td>[% dbname %]</td>
+    </tr>
+</table>
+<div><br></br></div>
+<table>
 
-<table border="2">
-
-    <tr align="RIGHT" valign="CENTER">
-        <th align="LEFT"> File </th>
-        [% FOREACH header = headers %]
-            <th> [% header %] </th>
-        [% END %]
+    <tr>
+    <th align="left" class="header"> File </th>
+    [% FOREACH header = headers %]
+        <th class="header"> [% header %] </th>
+    [% END %]
     </tr>
 
     [% FOREACH file = files %]
-        <tr align="RIGHT" valign="CENTER">
-            <td align="LEFT">
+        <tr align="center" valign="top">
+            <td align="left">
                 [% IF file_exists.$file %]
-                    <a href="[%- filenames.$file -%].html"> [% file %] </a>
+                   <a href="[%- filenames.$file -%].html"> [% file %] </a>
                 [% ELSE %]
                     [% file %]
                 [% END %]
             </td>
 
             [% FOREACH criterion = showing %]
-                [% IF vals.$file.$criterion.bg %]
-                    <td bgcolor="[%- vals.$file.$criterion.bg -%]">
+                [% IF vals.$file.$criterion.class %]
+                    <td class="[%- vals.$file.$criterion.class -%]"
+                        title="[%- vals.$file.$criterion.details -%]">
                 [% ELSE %]
                     <td>
                 [% END %]
+                [% IF vals.$file.$criterion.link.defined %]
+                    <a href="[% vals.$file.$criterion.link %]">
+                        [% vals.$file.$criterion.pc %]
+                    </a>
+                [% ELSE %]
                     [% vals.$file.$criterion.pc %]
+                [% END %]
                 </td>
             [% END %]
         </tr>
@@ -381,8 +397,6 @@ $Templates{summary} = <<'EOT';
 EOT
 
 $Templates{branches} = <<'EOT';
-[% PROCESS colours %]
-
 [% WRAPPER html %]
 
 <h1> [% title %] </h1>
@@ -417,8 +431,6 @@ $Templates{branches} = <<'EOT';
 EOT
 
 $Templates{conditions} = <<'EOT';
-[% PROCESS colours %]
-
 [% WRAPPER html %]
 
 <h1> [% title %] </h1>
@@ -462,8 +474,6 @@ $Templates{conditions} = <<'EOT';
 EOT
 
 $Templates{file} = <<'EOT';
-[% PROCESS colours %]
-
 [% WRAPPER html %]
 
 <h1> [% title %] </h1>
@@ -503,9 +513,10 @@ $Templates{file} = <<'EOT';
 [% END %]
 EOT
 
-1
+# remove some whitespace from templates
+s/^\s+//gm for values %Templates;
 
-__END__
+1;
 
 =head1 NAME
 
@@ -533,7 +544,7 @@ Huh?
 
 =head1 VERSION
 
-Version 0.50 - 25th October 2004
+Version 0.51 - 29th November 2004
 
 =head1 LICENCE
 
@@ -545,3 +556,74 @@ The latest version of this software should be available from my homepage:
 http://www.pjcj.net
 
 =cut
+
+package Devel::Cover::Report::Html_basic;
+
+__DATA__
+/* Stylesheet for Devel::Cover HTML reports */
+
+/* You may modify this file to alter the appearance of your coverage
+ * reports. If you do, you should probably flag it read-only to prevent
+ * future runs from overwriting it.
+ */
+
+/* Note: default values use the color-safe web palette. */
+
+body {
+    font-family: sans-serif;
+}
+
+h1 {
+    background-color: #3399ff;
+    border: solid 1px #999999;
+    padding: 0.2em;
+}
+
+a {
+    color: #000000;
+}
+a:visited {
+    color: #333333;
+}
+
+code {
+    white-space: pre;
+}
+
+table {
+/*    border: solid 1px #000000;*/
+/*    border-collapse: collapse;*/
+}
+td,th {
+    border: solid 1px #cccccc;
+}
+
+/* Classes for color-coding coverage information:
+ *   header    : column/row header
+ *   uncovered : path not covered or coverage < 75%
+ *   covered75 : coverage >= 75%
+ *   covered90 : coverage >= 90%
+ *   covered   : path covered or coverage = 100%
+ */
+.header {
+    background-color:  #cccccc;
+    border: solid 1px #333333;
+    padding-left:  0.2em;
+    padding-right: 0.2em;
+}
+.uncovered {
+    background-color:  #ff9999;
+    border: solid 1px #cc0000;
+}
+.covered75 {
+    background-color:  #ffcc99;
+    border: solid 1px #ff9933;
+}
+.covered90 {
+    background-color:  #ffff99;
+    border: solid 1px #cccc66;
+}
+.covered {
+    background-color:  #99ff99;
+    border: solid 1px #009900;
+}
