@@ -4,10 +4,10 @@ use strict;
 use warnings;
 use CGI;
 use Getopt::Long;
-use Devel::Cover::DB 0.50;
-use Devel::Cover::Truth_Table 0.50;
+use Devel::Cover::DB 0.51;
+use Devel::Cover::Truth_Table 0.51;
 
-our $VERSION = "0.50";
+our $VERSION = "0.51";
 
 #-------------------------------------------------------------------------------
 # Subroutine : get_coverage_for_line
@@ -82,12 +82,14 @@ sub get_showing_headers {
 sub truth_table {
     return if @_ > 16;
     my @lops;
+    my $n = 0;
     foreach my $c (@_) {
         my $op = $c->[1]{type};
         my @hit = map {defined() && $_ > 0 ? 1 : 0} @{$c->[0]};
         @hit = reverse @hit if $op =~ /^or_[23]$/;
         my $t = {
             tt   => Devel::Cover::Truth_Table->new_primitive($op, @hit),
+            # tt   => Devel::Cover::Truth_Table->new_primitive($op, $c, $n++);
             cvg  => $c->[1],
             expr => join(' ', @{$c->[1]}{qw/left op right/}),
         };
@@ -210,6 +212,7 @@ sub _branch_report {
 #-------------------------------------------------------------------------------
 sub _condition_report {
     my $coverage = shift;
+    # use Data::Dumper; print STDERR Dumper $coverage;
 
     my @tables = truth_table(@{$coverage->{condition}});
     return unless @tables;
@@ -254,7 +257,7 @@ sub print_html_header {
 
     print $fh <<"END_HTML";
 <!--
-This file was generated by Devel::Cover Version 0.50
+This file was generated by Devel::Cover Version 0.51
 Devel::Cover is copyright 2001-2004, Paul Johnson (pjcj\@cpan.org)
 Devel::Cover is free. It is licensed under the same terms as Perl itself.
 The latest version of Devel::Cover should be available from my homepage:
@@ -772,7 +775,7 @@ Devel::Cover
 
 =head1 VERSION
 
-Version 0.50 - 25th October 2004
+Version 0.51 - 29th November 2004
 
 =head1 LICENCE
 
